@@ -1,10 +1,11 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-MissingH-1.3.0.1/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: MissingH
-version: 1.2.0.2
-id: MissingH-1.2.0.2-bdb2b90bd23e2710dd9d3d70ffd68958
+version: 1.3.0.1
+id: MissingH-1.3.0.1-2d288cd50d5fdf3020d02b53b7d3114d
 
 license: BSD3
-copyright: Copyright (c) 2004-2011 John Goerzen
+copyright: Copyright (c) 2004-2014 John Goerzen
 maintainer: John Goerzen <jgoerzen@complete.org>
 stability: Beta
 homepage: http://software.complete.org/missingh
@@ -35,35 +36,35 @@ exposed-modules: Data.String.Utils System.IO.Utils System.IO.Binary
                  Data.MIME.Types System.Console.GetOpt.Utils
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/MissingH-1.2.0.2
-library-dirs: /usr/local/lib/ghc/MissingH-1.2.0.2
-hs-libraries: HSMissingH-1.2.0.2
+import-dirs: /usr/local/lib/ghc/MissingH-1.3.0.1
+library-dirs: /usr/local/lib/ghc/MissingH-1.3.0.1
+hs-libraries: HSMissingH-1.3.0.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: HUnit-1.2.5.2-6e02ecc15e3cc5ab8ef10df50d05a1a9
-         array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
-         base-4.6.0.1-6b06c3defb20732cfd08deb8ba52ca7c
-         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
-         directory-1.2.0.1-1e5a1d00411e436c303c3932f4640124
-         filepath-1.3.0.1-b12cbe18566fe1532a1fda4c85e31cbe
-         hslogger-1.2.3-1c3c23ebbac9f581fe472dd65ddc9b94
-         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
-         network-2.4.1.2-d8af12af3edec327865681988e18696b
-         old-locale-1.0.0.5-6729cb9d9cc62d150655de8fc5401b91
-         old-time-1.1.0.1-2f8ea093d0c7014780a8a5772f948883
-         parsec-3.1.3-83475a11f2461aa1a11fb4b6a9cf137c
-         process-1.1.0.2-76e05340eb66705981411022731ca84a
-         random-1.0.1.1-49dee13e6169a73481e9624e99220b78
-         regex-compat-0.95.1-5aa32e2bfd54140cd88d19d49933a997
-         time-1.4.0.1-10dc4804a19dc0000fab79908f1a9f50
-         unix-2.6.0.1-eff76fcbf6509b60a4df5e8289027c63
+depends: HUnit-1.2.5.2-787adf4463330986350e972335672d3e
+         array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         containers-0.5.5.1-d4bd887fb97aa3a46cbadc13709b7653
+         directory-1.2.1.0-255ee2a4a618c74613f025ccc4ecc082
+         filepath-1.3.0.2-25a474a9272ae6260626ce0d70ad1cab
+         hslogger-1.2.9-2ad9d468141b6a9cfdad083a5e6f4978
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         network-2.4.2.3-878f8bfcc369ed62265df39b168036b0
+         old-locale-1.0.0.6-50b0125c49f76af85dc7aa22975cdc34
+         old-time-1.1.0.2-e3f776e97c1a6ff1770b04943a7ef7c6
+         parsec-3.1.5-7f6674da593b27c3fdd904274a0dcd1e
+         process-1.2.0.0-891670ec11c8b086a673596aa083f351
+         random-1.0.1.1-18033e0e7d0ae09dc4f8adbdce56b966
+         regex-compat-0.95.1-ffcffda19446371b30a2ddb898e02cfe
+         time-1.4.2-311aa8e77a6af87dc3d662d572df62ec
+         unix-2.7.0.1-49291e6beb52ca8844af5af8283d8383
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-MissingH-1.2.0.2/html/MissingH.haddock
-haddock-html: /usr/local/share/doc/hs-MissingH-1.2.0.2/html
+haddock-interfaces: /usr/local/share/doc/hs-MissingH-1.3.0.1/html/MissingH.haddock
+haddock-html: /usr/local/share/doc/hs-MissingH-1.3.0.1/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
